@@ -100,12 +100,12 @@ class ServerObjectCache(object):
         # - value: dictionary of named lists:
         #   - key: list name
         #   _ value: list of CIM objects (e.g. CIMInstanceName, CIMClass)
-        self._server_dict = dict()
+        self._server_dict = {}
 
     def add_list(self, server_url, list_name, obj_list):
         """Add obj_list to the list named list_name"""
         if server_url not in self._server_dict:
-            self._server_dict[server_url] = dict()
+            self._server_dict[server_url] = {}
         list_dict = self._server_dict[server_url]
         if list_name in list_dict:
             raise KeyError(
@@ -274,7 +274,7 @@ class WBEMConnectionAsserted(WBEMConnection):
         Return an AssertionError about the specified exception.
         """
         parm_list = ["{0!r}".format(a) for a in args]
-        parm_list.extend(["{0}={1!r}".format(k, kwargs[k]) for k in kwargs])
+        parm_list.extend(["{0}={1!r}".format(k, v) for k, v in kwargs.items()])
         parm_str = ", ".join(parm_list)
         return AssertionError(
             "Server {0} at {1}: WBEMConnection.{2}() failed and raised "
@@ -454,7 +454,7 @@ def server_func_asserted(server, funcname, *args, **kwargs):
         return func(*args, **kwargs)
     except Error as exc:
         parm_list = ["{0!r}".format(a) for a in args]
-        parm_list.extend(["{0}={1!r}".format(k, kwargs[k]) for k in kwargs])
+        parm_list.extend(["{0}={1!r}".format(k, v) for k, v in kwargs.items()])
         parm_str = ", ".join(parm_list)
         raise AssertionError(
             "Server {0} at {1}: Calling WBEMServer.{2}() failed and "
