@@ -302,9 +302,8 @@ class YamlItem(pytest.Item):
         """
         runtestcase(self.testcase)
 
-    @staticmethod
-    def repr_failure(excinfo, style=None):
-        # pylint: disable=unused-argument
+    def repr_failure(self, excinfo, style=None):
+        # pylint: disable=unused-argument,no-self-use
         """
         Called by py.test when the runtest() method raised an exception, to
         provide details about the failure.
@@ -421,13 +420,12 @@ def obj(value, tc_name):
                 if arg_name == "pywbem_object":
                     continue
                 ctor_args[arg_name] = obj(value[arg_name], tc_name)
-            with pytest.warns(None) as rec_warnings:
+            with warnings.catch_warnings(record=True) as rec_warnings:
                 obj_ = ctor_call(**ctor_args)
-            if rec_warnings:
-                for w in rec_warnings.list:
-                    # Ignore DeprecationWarnings, re-issue any others
-                    if w.category != DeprecationWarning:
-                        warnings.warn(w.message, w.category, 1)
+            for w in rec_warnings:
+                # Ignore DeprecationWarnings, re-issue any others
+                if w.category != DeprecationWarning:
+                    warnings.warn(w.message, w.category, 1)
         else:
             obj_ = OrderedDict()
             for key in value:
@@ -891,10 +889,10 @@ def runtestcase(testcase):
         raise ClientTestError("Unknown operation name: %s" % op_name)
 
     # Invoke the PyWBEM operation to be tested
+    raised_exception = None
+    raised_traceback_str = None  # avoid pylint warning used-before-assignment
     try:
         result = op_call(**op_args)
-        raised_exception = None
-
     except Exception as exc:      # pylint: disable=broad-except
         raised_exception = exc
         stringio = six.StringIO()
@@ -1200,10 +1198,10 @@ def result_tuple(value, tc_name):
     # test for both paths and instances.
     objs = None
     if "query_result_class" in value:
-        result = namedtuple("exp_result", ["instances", "eos", "context",
-                                           "query_result_class"])
+        result = namedtuple("result", ["instances", "eos", "context",
+                                       "query_result_class"])
     else:
-        result = namedtuple("exp_result", ["instances", "eos", "context"])
+        result = namedtuple("result", ["instances", "eos", "context"])
 
     # either path or instances should be in value
     if "instances" in value:
