@@ -17,6 +17,8 @@ pywbem = import_installed('pywbem')
 from pywbem import _cim_http, MissingKeybindingsWarning  # noqa: E402
 # pylint: enable=wrong-import-position, wrong-import-order, invalid-name
 
+# Literal form {"blah: 0} faster than dict(blah=0) but same functionality
+# pylint: disable=use-dict-literal
 
 # These defaults are defined separately from those in _cim_constants.py to
 # ensure that changes of the defaults are caught.
@@ -27,6 +29,9 @@ DEFAULT_SCHEME = 'http'
 # Keep in sync with same value in _cim_http.py
 HTTP_CONNECT_TIMEOUT = 9.99
 
+URLLIB3_VERSION = tuple(map(int, urllib3.__version__.split('.')[0:3]))
+URLLIB3V2 = URLLIB3_VERSION >= (2, 0, 0)
+
 TESTCASES_PARSE_URL = [
 
     # Testcases for _cim_http.parse_url()
@@ -621,9 +626,12 @@ def test_parse_url(
 
 
 DUMMY_CONN_USING_HTTPS = pywbem.WBEMConnection('https://dummy')
-DUMMY_CONN_USING_HTTP = pywbem.WBEMConnection('http://dummy')
+DUMMY_CONN_USING_HTTP = pywbem.WBEMConnection(url='http://dummy')
 DUMMY_POOL = urllib3.connectionpool.HTTPConnectionPool('dummy')
 
+# Argument for NewConnectionError which changes first parameter from
+# urllib3 version 1.x to urllib3 version 2.0 (from pool to host).
+NEW_CONN_ERR_PARM1 = DUMMY_CONN_USING_HTTP if URLLIB3V2 else DUMMY_POOL
 
 TESTCASES_PYWBEM_REQUESTS_EXCEPTION = [
 
@@ -831,12 +839,12 @@ TESTCASES_PYWBEM_REQUESTS_EXCEPTION = [
                         pool=DUMMY_POOL,
                         url='http://dummy',
                         reason=urllib3.exceptions.NewConnectionError(
-                            pool=DUMMY_POOL,
+                            NEW_CONN_ERR_PARM1,
                             message="bla"))),
                 conn=DUMMY_CONN_USING_HTTP,
             ),
             exp_exc_type=pywbem.ConnectionError,
-            exp_pattern="^bla$",
+            exp_pattern="^bla$"
         ),
         None, None, True
     ),
@@ -881,14 +889,14 @@ def test_pywbem_requests_exception(
     act_message = str(act_exc)
 
     # Verify the result
-    # pylint: disable=unidiomatic-typecheck
+    # pylint: disable=unidiomatic-typecheck,line-too-long
     assert type(act_exc) == exp_exc_type, \
         "Unexpected exception type:\n" \
         "  Actual type: {}\n" \
         "  Expected type: {}\n" \
         "  Actual message: {}\n" \
         "  Expected message pattern: {}\n". \
-        format(type(act_exc), exp_exc_type, act_message, exp_pattern)
+        format(type(act_exc), exp_exc_type, act_message, exp_pattern)  # noqa: E721,E501
     assert re.search(exp_pattern, act_message), \
         "Unexpected exception message:\n" \
         "  Actual: {}\n" \
