@@ -23,33 +23,38 @@ from pywbem import WBEMListener, ListenerPortError  # noqa: E402
 from pywbem._utils import _format  # noqa: E402
 # pylint: enable=wrong-import-position, wrong-import-order, invalid-name
 
+# Literal form {"blah: 0} faster than dict(blah=0) but same functionality
+# pylint: disable=use-dict-literal
+
 # Log level to be used. To enable logging, change this constant to the desired
 # log level, and add code to set or unset the log level of the root logger
 # globally or specifically in each test case.
 LOGLEVEL = logging.NOTSET  # NOTSET disables logging
+# LOGLEVEL = logging.DEBUG   # Enable to generate logs at debug level
 
-# Name of the log file
-LOGFILE = 'test_indicationlistener.log'
+# Set name of the log file
+LOG_NAME = 'test_indicationlistener'
+LOGFILE = LOG_NAME + '.log'
 
 
 def configure_root_logger(logfile):
     """
-    Configure the root logger, except for log level
+    Configure the root logger, except for log level. Add or configure
+    a single file handler for the log with our formatter and logfile name
     """
     root_logger = logging.getLogger('')
-    hdlr_exists = False
     for hdlr in root_logger.handlers:
         if isinstance(hdlr, logging.FileHandler):
-            hdlr_exists = True
-    if not hdlr_exists:
-        hdlr = logging.FileHandler(logfile)
-        hdlr.setFormatter(
-            logging.Formatter(
-                "%(asctime)s %(thread)s %(name)s %(levelname)s %(message)s"))
-        root_logger.addHandler(hdlr)
+            root_logger.removeHandler(hdlr)
+    # add Filehandler with logfile name and our formatter
+    hdlr = logging.FileHandler(logfile)
+    hdlr.setFormatter(
+        logging.Formatter(
+            "%(asctime)s %(thread)s %(name)s %(levelname)s %(message)s"))
+    root_logger.addHandler(hdlr)
 
 
-LOGGER = logging.getLogger('test_indicationlistener')
+LOGGER = logging.getLogger(LOG_NAME)
 if LOGLEVEL > logging.NOTSET:
     configure_root_logger(LOGFILE)
 
@@ -229,6 +234,27 @@ TESTCASES_WBEMLISTENER_INIT = [
         ),
         None, None, True
     ),
+    (
+        "Verify use of direct_call argument",
+        dict(
+            init_args=[],
+            init_kwargs=dict(
+                host='woot.com',
+                http_port=None,
+                https_port=6998,
+                certfile='certfile.pem',
+                keyfile='keyfile.pem',
+            ),
+            exp_attrs=dict(
+                host='woot.com',
+                http_port=None,
+                https_port=6998,
+                certfile='certfile.pem',
+                keyfile='keyfile.pem',
+            ),
+        ),
+        None, None, True
+    ),
 
     # Failure cases
     (
@@ -609,6 +635,7 @@ def process_indication(indication, host):
 @pytest.mark.parametrize(
     "send_count",
     [1, 10, 100]  # 1000 in some environments takes 30 min
+
 )
 def test_WBEMListener_send_indications(send_count):
     """
@@ -618,10 +645,14 @@ def test_WBEMListener_send_indications(send_count):
     parameter using HTTP. It confirms that they are all received by the
     listener.
 
-    This test validates the main paths of the listener and that the listener can
-    receive large numbers of indications without duplicates or dropping
+    This test validates the main paths of the listener and that the listener
+    can receive large numbers of indications without duplicates or dropping
     indications.
 
+    The test generates the indications itself and does not depend on a
+    WBEM Server.  Tests in tests/end2end test with indications from
+    a WBEM server.
+
     It does not validate all of the possible xml options on indications.
 
     Creates the listener, starts the listener, creates the indication XML and
@@ -651,6 +682,7 @@ def test_WBEMListener_send_indications(send_count):
     listener = WBEMListener(host, http_port)
     listener.add_callback(process_indication)
     listener.start()
+    timer = ElapsedTimer()
 
     try:
 
@@ -669,11 +701,10 @@ def test_WBEMListener_send_indications(send_count):
 
         delta_time = time() - start_time
         random_base = randint(1, 10000)
-        timer = ElapsedTimer()
 
         RCV_COUNT = 0
         RCV_ERRORS = False
-
+        LOGGER.debug("Testcase sending %s indications", send_count)
         for i in range(send_count):
 
             msg_id = random_base + i
@@ -685,11 +716,12 @@ def test_WBEMListener_send_indications(send_count):
             try:
                 response = post_bsl(url, headers=headers, data=payload)
             except requests.exceptions.RequestException as exc:
-                msg = ("Testcase sending indication #{} raised {}: {}".
-                       format(i, exc.__class__.__name__, exc))
+                msg = ("Testcase sending indication #{} raised {}: {}",
+                       (i, exc.__class__.__name__, exc))
                 LOGGER.error(msg)
                 new_exc = AssertionError(msg)
-                new_exc.__cause__ = None  # Disable to see original traceback
+                # Disable to see original traceback
+                new_exc.__cause__ = None
                 raise new_exc
 
             LOGGER.debug("Testcase received response from sending "
@@ -701,16 +733,9 @@ def test_WBEMListener_send_indications(send_count):
                 LOGGER.error(msg)
                 raise AssertionError(msg)
 
-        endtime = timer.elapsed_sec()
-
         # Make sure the listener thread has processed all indications
         sleep(1)
 
-        if VERBOSE_SUMMARY:
-            print("\nSent {} indications in {} sec or {:.2f} ind/sec".
-                  format(send_count, endtime, (send_count / endtime)))
-            sys.stdout.flush()
-
         assert not RCV_ERRORS, \
             "Errors occurred in process_indication(), as printed to stdout"
 
@@ -719,8 +744,21 @@ def test_WBEMListener_send_indications(send_count):
             format(send_count, RCV_COUNT)
 
     finally:
-        listener.stop()
 
+        endtime = timer.elapsed_sec()
+        per_sec = send_count / endtime
+
+        LOGGER.debug("SUMMARY: Sent %d indications in %d sec or %.2f ind/sec",
+                     send_count, endtime, per_sec)
+
+        if VERBOSE_SUMMARY:
+            print("\nSSUMMARY: Sent {} indications in {} sec or {:.2f} ind/sec".
+                  format(send_count, endtime, per_sec))
+            sys.stdout.flush()
+
+        LOGGER.debug("Start listener stop")
+        listener.stop()
+        LOGGER.debug("End listener stop")
         # Disable logging for this test function
         if LOGLEVEL > logging.NOTSET:
             logging.getLogger('').setLevel(logging.NOTSET)
